# RADICAL-SAGA (RS)

[![Build Status](https://travis-ci.org/radical-cybertools/radical.saga.svg?branch=devel)](https://travis-ci.org/radical-cybertools/radical.saga)

RADICAL-SAGA (RS) is a Python package that implements the interface
specification of the Open Grid Forum (OGF) Simple API for Grid Applications
(SAGA) standard. RS works as a light-weight access layer for distributed
computing infrastructures, providing adaptors for different middleware 
systems and services.

## Documentation

Full package description and usage examples are available at:  
https://radicalsaga.readthedocs.io/en/stable/

Additional information is provided in the
[wiki](https://github.com/radical-cybertools/radical.saga/wiki) section of RS
GitHub repository.

## Code

Generally, the `master` branch reflects the RS release published on
[PyPI](https://pypi.org/project/radical.saga/).

The `devel` branch (and any branch other than master) may not correspond to the
published documentation and, specifically, may have dependencies which need to
be resolved manually.
